pub struct get_owner_dues_by_acp;Expand description
GET /api/v1/stats/owner/dues-by-acp
Ce que le copropriétaire doit, ventilé par association.
Séparée de /stats/owner parce qu’elle répond à une autre question : celle
-là dit « combien », celle-ci dit « à QUI ». Un copropriétaire peut détenir
des lots dans plusieurs ACP, et chacune est une personne morale avec son
propre compte bancaire (Art. 3.86  1er et  3).
Un montant global laisse croire qu’un virement unique suffit ; il paierait la mauvaise personne morale pour une partie de la somme (#867).